pub struct CommandOut {
pub stdout: String,
pub stderr: String,
pub status: ExitStatus,
}Expand description
CommandOut struct is used to store the output and error of a command execution.
Fields
stdout: Stringstdout is the standard output of the command execution.
stderr: Stringerror is the standard error of the command execution.
status: ExitStatusstatus is the exit status of the command execution.