Module timer

Module timer 

timer module provides functions and structs for creating and managing timers. It allows the user to schedule tasks to be executed at a specific time or interval.

use doe::run_timer;
fn run(){
    println!("running ");
}
  run_timer(std::time::Instant::now(),std::time::Duration::from_secs(1),std::time::Duration::from_secs(5),Box::new(run));

Modules

impl_timer